Class: Aws::MediaPackageVod::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaPackageVod::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediapackagevod/client.rb,
sig/client.rbs
Overview
An API client for MediaPackageVod. To construct a client, you need to configure a :region and :credentials.
client = Aws::MediaPackageVod::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _ConfigureLogsResponseSuccess, _CreateAssetResponseSuccess, _CreatePackagingConfigurationResponseSuccess, _CreatePackagingGroupResponseSuccess, _DeleteAssetResponseSuccess, _DeletePackagingConfigurationResponseSuccess, _DeletePackagingGroupResponseSuccess, _DescribeAssetResponseSuccess, _DescribePackagingConfigurationResponseSuccess, _DescribePackagingGroupResponseSuccess, _ListAssetsResponseSuccess, _ListPackagingConfigurationsResponseSuccess, _ListPackagingGroupsResponseSuccess, _ListTagsForResourceResponseSuccess, _UpdatePackagingGroupResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#configure_logs(params = {}) ⇒ Types::ConfigureLogsResponse
Changes the packaging group's properities to configure log subscription.
-
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new MediaPackage VOD Asset resource.
-
#create_packaging_configuration(params = {}) ⇒ Types::CreatePackagingConfigurationResponse
Creates a new MediaPackage VOD PackagingConfiguration resource.
-
#create_packaging_group(params = {}) ⇒ Types::CreatePackagingGroupResponse
Creates a new MediaPackage VOD PackagingGroup resource.
-
#delete_asset(params = {}) ⇒ Struct
Deletes an existing MediaPackage VOD Asset resource.
-
#delete_packaging_configuration(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingConfiguration resource.
-
#delete_packaging_group(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingGroup resource.
-
#describe_asset(params = {}) ⇒ Types::DescribeAssetResponse
Returns a description of a MediaPackage VOD Asset resource.
-
#describe_packaging_configuration(params = {}) ⇒ Types::DescribePackagingConfigurationResponse
Returns a description of a MediaPackage VOD PackagingConfiguration resource.
-
#describe_packaging_group(params = {}) ⇒ Types::DescribePackagingGroupResponse
Returns a description of a MediaPackage VOD PackagingGroup resource.
-
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Returns a collection of MediaPackage VOD Asset resources.
-
#list_packaging_configurations(params = {}) ⇒ Types::ListPackagingConfigurationsResponse
Returns a collection of MediaPackage VOD PackagingConfiguration resources.
-
#list_packaging_groups(params = {}) ⇒ Types::ListPackagingGroupsResponse
Returns a collection of MediaPackage VOD PackagingGroup resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_packaging_group(params = {}) ⇒ Types::UpdatePackagingGroupResponse
Updates a specific packaging group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1532 1533 1534 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1532 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1535 1536 1537 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1535 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1505 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaPackageVod') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediapackagevod' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#configure_logs(params = {}) ⇒ Types::ConfigureLogsResponse
Changes the packaging group's properities to configure log subscription
92 |
# File 'sig/client.rbs', line 92
def configure_logs: (
|
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new MediaPackage VOD Asset resource.
113 |
# File 'sig/client.rbs', line 113
def create_asset: (
|
#create_packaging_configuration(params = {}) ⇒ Types::CreatePackagingConfigurationResponse
Creates a new MediaPackage VOD PackagingConfiguration resource.
136 |
# File 'sig/client.rbs', line 136
def create_packaging_configuration: (
|
#create_packaging_group(params = {}) ⇒ Types::CreatePackagingGroupResponse
Creates a new MediaPackage VOD PackagingGroup resource.
218 |
# File 'sig/client.rbs', line 218
def create_packaging_group: (
|
#delete_asset(params = {}) ⇒ Struct
Deletes an existing MediaPackage VOD Asset resource.
235 |
# File 'sig/client.rbs', line 235
def delete_asset: (
|
#delete_packaging_configuration(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingConfiguration resource.
244 |
# File 'sig/client.rbs', line 244
def delete_packaging_configuration: (
|
#delete_packaging_group(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingGroup resource.
253 |
# File 'sig/client.rbs', line 253
def delete_packaging_group: (
|
#describe_asset(params = {}) ⇒ Types::DescribeAssetResponse
Returns a description of a MediaPackage VOD Asset resource.
271 |
# File 'sig/client.rbs', line 271
def describe_asset: (
|
#describe_packaging_configuration(params = {}) ⇒ Types::DescribePackagingConfigurationResponse
Returns a description of a MediaPackage VOD PackagingConfiguration resource.
289 |
# File 'sig/client.rbs', line 289
def describe_packaging_configuration: (
|
#describe_packaging_group(params = {}) ⇒ Types::DescribePackagingGroupResponse
Returns a description of a MediaPackage VOD PackagingGroup resource.
306 |
# File 'sig/client.rbs', line 306
def describe_packaging_group: (
|
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Returns a collection of MediaPackage VOD Asset resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
317 |
# File 'sig/client.rbs', line 317
def list_assets: (
|
#list_packaging_configurations(params = {}) ⇒ Types::ListPackagingConfigurationsResponse
Returns a collection of MediaPackage VOD PackagingConfiguration resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
330 |
# File 'sig/client.rbs', line 330
def list_packaging_configurations: (
|
#list_packaging_groups(params = {}) ⇒ Types::ListPackagingGroupsResponse
Returns a collection of MediaPackage VOD PackagingGroup resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
343 |
# File 'sig/client.rbs', line 343
def list_packaging_groups: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified resource.
354 |
# File 'sig/client.rbs', line 354
def list_tags_for_resource: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource. You can specify one or more tags to add.
360 |
# File 'sig/client.rbs', line 360
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource. You can specify one or more tags to remove.
367 |
# File 'sig/client.rbs', line 367
def untag_resource: (
|
#update_packaging_group(params = {}) ⇒ Types::UpdatePackagingGroupResponse
Updates a specific packaging group. You can't change the id attribute or any other system-generated attributes.
385 |
# File 'sig/client.rbs', line 385
def update_packaging_group: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1525 1526 1527 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1525 def waiter_names [] end |