Class: Aws::MediaPackageVod::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MediaPackageVod::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mediapackagevod/client.rb
Overview
An API client for MediaPackageVod. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MediaPackageVod::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#configure_logs(params = {}) ⇒ Types::ConfigureLogsResponse
Changes the packaging group’s properities to configure log subscription.
-
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new MediaPackage VOD Asset resource.
-
#create_packaging_configuration(params = {}) ⇒ Types::CreatePackagingConfigurationResponse
Creates a new MediaPackage VOD PackagingConfiguration resource.
-
#create_packaging_group(params = {}) ⇒ Types::CreatePackagingGroupResponse
Creates a new MediaPackage VOD PackagingGroup resource.
-
#delete_asset(params = {}) ⇒ Struct
Deletes an existing MediaPackage VOD Asset resource.
-
#delete_packaging_configuration(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingConfiguration resource.
-
#delete_packaging_group(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingGroup resource.
-
#describe_asset(params = {}) ⇒ Types::DescribeAssetResponse
Returns a description of a MediaPackage VOD Asset resource.
-
#describe_packaging_configuration(params = {}) ⇒ Types::DescribePackagingConfigurationResponse
Returns a description of a MediaPackage VOD PackagingConfiguration resource.
-
#describe_packaging_group(params = {}) ⇒ Types::DescribePackagingGroupResponse
Returns a description of a MediaPackage VOD PackagingGroup resource.
-
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Returns a collection of MediaPackage VOD Asset resources.
-
#list_packaging_configurations(params = {}) ⇒ Types::ListPackagingConfigurationsResponse
Returns a collection of MediaPackage VOD PackagingConfiguration resources.
-
#list_packaging_groups(params = {}) ⇒ Types::ListPackagingGroupsResponse
Returns a collection of MediaPackage VOD PackagingGroup resources.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_packaging_group(params = {}) ⇒ Types::UpdatePackagingGroupResponse
Updates a specific packaging group.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1532 1533 1534 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1532 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1535 1536 1537 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1535 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 1516 1517 1518 1519 1520 1521 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1505 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MediaPackageVod') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mediapackagevod' context[:gem_version] = '1.86.0' Seahorse::Client::Request.new(handlers, context) end |
#configure_logs(params = {}) ⇒ Types::ConfigureLogsResponse
Changes the packaging group’s properities to configure log subscription
520 521 522 523 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 520 def configure_logs(params = {}, = {}) req = build_request(:configure_logs, params) req.send_request() end |
#create_asset(params = {}) ⇒ Types::CreateAssetResponse
Creates a new MediaPackage VOD Asset resource.
585 586 587 588 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 585 def create_asset(params = {}, = {}) req = build_request(:create_asset, params) req.send_request() end |
#create_packaging_configuration(params = {}) ⇒ Types::CreatePackagingConfigurationResponse
Creates a new MediaPackage VOD PackagingConfiguration resource.
835 836 837 838 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 835 def create_packaging_configuration(params = {}, = {}) req = build_request(:create_packaging_configuration, params) req.send_request() end |
#create_packaging_group(params = {}) ⇒ Types::CreatePackagingGroupResponse
Creates a new MediaPackage VOD PackagingGroup resource.
895 896 897 898 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 895 def create_packaging_group(params = {}, = {}) req = build_request(:create_packaging_group, params) req.send_request() end |
#delete_asset(params = {}) ⇒ Struct
Deletes an existing MediaPackage VOD Asset resource.
916 917 918 919 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 916 def delete_asset(params = {}, = {}) req = build_request(:delete_asset, params) req.send_request() end |
#delete_packaging_configuration(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingConfiguration resource.
937 938 939 940 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 937 def delete_packaging_configuration(params = {}, = {}) req = build_request(:delete_packaging_configuration, params) req.send_request() end |
#delete_packaging_group(params = {}) ⇒ Struct
Deletes a MediaPackage VOD PackagingGroup resource.
958 959 960 961 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 958 def delete_packaging_group(params = {}, = {}) req = build_request(:delete_packaging_group, params) req.send_request() end |
#describe_asset(params = {}) ⇒ Types::DescribeAssetResponse
Returns a description of a MediaPackage VOD Asset resource.
1005 1006 1007 1008 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1005 def describe_asset(params = {}, = {}) req = build_request(:describe_asset, params) req.send_request() end |
#describe_packaging_configuration(params = {}) ⇒ Types::DescribePackagingConfigurationResponse
Returns a description of a MediaPackage VOD PackagingConfiguration resource.
1117 1118 1119 1120 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1117 def describe_packaging_configuration(params = {}, = {}) req = build_request(:describe_packaging_configuration, params) req.send_request() end |
#describe_packaging_group(params = {}) ⇒ Types::DescribePackagingGroupResponse
Returns a description of a MediaPackage VOD PackagingGroup resource.
1160 1161 1162 1163 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1160 def describe_packaging_group(params = {}, = {}) req = build_request(:describe_packaging_group, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsResponse
Returns a collection of MediaPackage VOD Asset resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1206 1207 1208 1209 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1206 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_packaging_configurations(params = {}) ⇒ Types::ListPackagingConfigurationsResponse
Returns a collection of MediaPackage VOD PackagingConfiguration resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1321 1322 1323 1324 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1321 def list_packaging_configurations(params = {}, = {}) req = build_request(:list_packaging_configurations, params) req.send_request() end |
#list_packaging_groups(params = {}) ⇒ Types::ListPackagingGroupsResponse
Returns a collection of MediaPackage VOD PackagingGroup resources.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1365 1366 1367 1368 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1365 def list_packaging_groups(params = {}, = {}) req = build_request(:list_packaging_groups, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of the tags assigned to the specified resource.
1393 1394 1395 1396 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1393 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource. You can specify one or more tags to add.
1420 1421 1422 1423 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1420 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource. You can specify one or more tags to remove.
1445 1446 1447 1448 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1445 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_packaging_group(params = {}) ⇒ Types::UpdatePackagingGroupResponse
Updates a specific packaging group. You can’t change the id attribute or any other system-generated attributes.
1496 1497 1498 1499 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1496 def update_packaging_group(params = {}, = {}) req = build_request(:update_packaging_group, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1525 1526 1527 |
# File 'lib/aws-sdk-mediapackagevod/client.rb', line 1525 def waiter_names [] end |